@@ -1,5 +1,5 @@
 /*
- * "$Id: testmxml.c 270 2007-04-23 21:48:03Z mike $"
+ * "$Id: testmxml.c 381 2009-02-05 06:06:11Z mike $"
  *
  * Test program for Mini-XML, a small XML-like file parsing library.
  *
@@ -30,11 +30,9 @@
 
 #include "config.h"
 #include "mxml.h"
-#ifdef WIN32
-#  include <io.h>
-#else
+#ifndef WIN32
 #  include <unistd.h>
-#endif /* WIN32 */
+#endif /* !WIN32 */
 #include <fcntl.h>
 #ifndef O_BINARY
 #  define O_BINARY 0
@@ -452,8 +450,7 @@ main(int  argc,				/* I - Number of command-line args */
       return (1);
     }
 
-    if ((node = mxmlFindElement(node, tree, "choice", NULL, NULL,
-                                MXML_NO_DESCEND)) == NULL)
+    if (!mxmlFindElement(node, tree, "choice", NULL, NULL, MXML_NO_DESCEND))
     {
       fputs("Unable to find second <choice> element in XML tree!\n", stderr);
       mxmlDelete(tree);
@@ -539,7 +536,7 @@ main(int  argc,				/* I - Number of command-line args */
   memset(event_counts, 0, sizeof(event_counts));
 
   if (argv[1][0] == '<')
-    tree = mxmlSAXLoadString(NULL, argv[1], type_cb, sax_cb, NULL);
+    mxmlSAXLoadString(NULL, argv[1], type_cb, sax_cb, NULL);
   else if ((fp = fopen(argv[1], "rb")) == NULL)
   {
     perror(argv[1]);
@@ -551,7 +548,7 @@ main(int  argc,				/* I - Number of command-line args */
     * Read the file...
     */
 
-    tree = mxmlSAXLoadFile(NULL, fp, type_cb, sax_cb, NULL);
+    mxmlSAXLoadFile(NULL, fp, type_cb, sax_cb, NULL);
 
     fclose(fp);
   }
@@ -710,7 +707,10 @@ whitespace_cb(mxml_node_t *node,	/* I - Element node */
   }
   else if (!strncmp(name, "?xml", 4))
   {
-    return (NULL);
+    if (where == MXML_WS_AFTER_OPEN)
+      return ("\n");
+    else
+      return (NULL);
   }
   else if (where == MXML_WS_BEFORE_OPEN ||
            ((!strcmp(name, "choice") || !strcmp(name, "option")) &&
@@ -744,5 +744,5 @@ whitespace_cb(mxml_node_t *node,	/* I - Element node */
 
 
 /*
- * End of "$Id: testmxml.c 270 2007-04-23 21:48:03Z mike $".
+ * End of "$Id: testmxml.c 381 2009-02-05 06:06:11Z mike $".
  */
